import createQueue from "./createQueue";

describe("createQueue", () => {
  let context;
  let queueName;
  let options;
  let processorFn;

  beforeEach(() => {
    context = {
      bullQueue: {
        jobQueues: {}
      }
    };
    queueName = "testQueue";
    options = {
      jobName: "testJob"
    };
    processorFn = jest.fn();
  });

  test("should create a new queue and add it to the jobQueues", () => {
    const newQueue = createQueue(context, queueName, options, processorFn);

    expect(newQueue).toBeDefined();
    expect(context.bullQueue.jobQueues[queueName]).toBe(newQueue);
  });

  test("should process jobs if REACTION_WORKERS_ENABLED is true", () => {
    global.REACTION_WORKERS_ENABLED = true;

    createQueue(context, queueName, options, processorFn);

    expect(context.bullQueue.jobQueues[queueName].process).toHaveBeenCalled();
  });

  test("should not process jobs if REACTION_WORKERS_ENABLED is false", () => {
    global.REACTION_WORKERS_ENABLED = false;

    createQueue(context, queueName, options, processorFn);

    expect(context.bullQueue.jobQueues[queueName].process).not.toHaveBeenCalled();
  });

  test("should use defaultOptions if options are not provided", () => {
    const newQueue = createQueue(context, queueName, undefined, processorFn);

    expect(newQueue).toBeDefined();
    expect(context.bullQueue.jobQueues[queueName]).toBe(newQueue);
  });
});
